﻿;-------------------------------------------------------------------------------
; randomly tilted ellipses with the sun at a focus point
;-------------------------------------------------------------------------------
; http://www.cs.cornell.edu/cv/OtherPdf/Ellipse.pdf
;
; given Focus1 = (x1, x2), Focus2 = (x2, y2) and s, we get:
; (intermediate: dx = x2 - x1, dy = y2 - y1)
;
; a = s/2, h = (x1+x2)/2, k = (y1+y2)/2, Tau = arctan(dy/dx)
; and b = Sqrt(s*s - (dx*dx + dy*dy)/2)
;-------------------------------------------------------------------------------



;-------------------------------------------------------------------------------
LV_Planets: ; set up ListView with planet data
;-------------------------------------------------------------------------------
    LV_Box(Planets, [
    ( LTrim Join, Comments
        ; content     header            options
        [" A_Index "," #    "," AutoHdr Integer Center "]
        [" Tick    "," Tick "," AutoHdr  Float  Right  "]
        [" x1      "," x1   "," AutoHdr  Float  Right  "]
        [" x2      "," x2   "," AutoHdr  Float  Right  "]
        [" dx      "," dx   "," AutoHdr  Float  Right  "]
        [" y1      "," y1   "," AutoHdr  Float  Right  "]
        [" y2      "," y2   "," AutoHdr  Float  Right  "]
        [" dy      "," dy   "," AutoHdr  Float  Right  "]
        [" cc4     "," cc4  "," AutoHdr  Float  Right  "]
        [" c2      "," c2   "," AutoHdr  Float  Right  "]
        [" s       "," s    "," AutoHdr  Float  Right  "]
        [" a       "," a    "," AutoHdr  Float  Right  "]
        [" b       "," b    "," AutoHdr  Float  Right  "]
        [" h       "," h    "," AutoHdr  Float  Right  "]
        [" k       "," k    "," AutoHdr  Float  Right  "]
        [" Tau     "," Tau  "," AutoHdr  Float  Right  "]
    )], 50, 50, 970, 720)

Return



;-------------------------------------------------------------------------------
Init_Planets: ; create random planets
;-------------------------------------------------------------------------------
    Planets := {}
    Size := SunSize + PlanetSize

    Loop, %PlanetCount% {
        Planets[A_Index] := {
        ( LTrim Join, Comments
            ;-----------------------------------; - start with data -
            Tick: Rnd(1, 360)                   ; random tick - indep. var
            ;
            x1: (x1 := MidX)                    ; Focus1 x-coord fixed
            x2: (x2 := Rnd(0.5, 1.5) * MidX)    ; Focus2 x-coord random
            dx: (dx := x2 - x1)                 ; horz distance between 2 foci
            ;
            y1: (y1 := MidY)                    ; Focus1 y-coord fixed
            y2: (y2 := Rnd(0.5, 1.5) * MidY)    ; Focus2 y-coord random
            dy: (dy := y2 - y1)                 ; vert distance between 2 foci
            ;
            ;-----------------------------------; intermeditate values
            cc4: (cc4 := dx*dx + dy*dy)         ; square over 2c (4*c*c)
            c2: (c2 := Sqrt(cc4))               ; 2*c
            ;
            ;-----------------------------------; random data:
            s: s := Rnd(c2+1.2*Size, c2+8*Size) ; random length of string
            ;
            ;-----------------------------------; 5 needed vars for formulas
            a: s/2                              ; semi-axis #1
            b: Sqrt(s*s - cc4) /2               ; semi-axis #2
            h: (x1 + x2) /2                     ; x-coord of Center
            k: (y1 + y2) /2                     ; y-coord of Center
            Tau: ATan(dy/dx)                    ; tilt
        )}
    }

Return



;-------------------------------------------------------------------------------
NewPositions: ; calculate new positions
;-------------------------------------------------------------------------------
    For each, P in Planets {
        P.Tick := Mod(P.Tick + 1, 360)  ; increment Tick
        t := P.Tick * Pi / 180          ; convert to radians

        P.PosX := P.h + P.a*Cos(t)*Cos(P.Tau) - P.b*Sin(t)*Sin(P.Tau)
        P.PosY := P.k + P.a*Cos(t)*Sin(P.Tau) + P.b*Sin(t)*Cos(P.Tau)
    }

Return
