﻿


;-------------------------------------------------------------------------------
LV_Box(Table, oConfig, X := "", Y := "", Width := 400, Height := 200) {
;-------------------------------------------------------------------------------
    ; display a table in an ListView control
    ; no return value
    ;
    ; Table     is the name of the table to show
    ; oConfig   describes the columns to show
    ; X         is the initial x-coord of the GUI
    ; Y         is the initial y-coord of the GUI
    ; Width     is the initial width of the GUI
    ; Height    is the initial height of the GUI
    ;
    ; Note 1:
    ;           The first column is hard coded to contain the row index. The
    ;           first entry in oConfig may contain any string but to keep the
    ;           code clear the user should write "A_Index".
    ; Note 2:
    ;           The function automatically adds a final column which makes
    ;           programmatically adjusting the width of the "real" last column
    ;           easy and independent of the GUI's width.
    ;---------------------------------------------------------------------------

    Coords := (X = "" ? "" : "x" X) (Y = "" ? "" : " y" Y)

    Col := []
    For each, Column in oConfig
        If (A_Index > 1)
            Col[A_Index] := Trim(Column[1])
    ColumnCount := oConfig.Length()

    For each, Column in oConfig
        Headers .= Trim(Column[2]) "|"

    Gui, LV_Box: New,, %AppName%
    Gui, +Resize -MinimizeBox -MaximizeBox
    Gui, Margin, 0, 0
    Gui, Add, ListView, w%Width% h%Height% Grid, %Headers%%A_Space%

    For each, Row in Table {
        Private := []
        Loop, % ColumnCount - 1
            Private.Push(Row[Col[A_Index + 1]])
        LV_Add("", A_Index, Private*)
    }

    For each, Column in oConfig
        LV_ModifyCol(A_Index, Column[3])
    LV_ModifyCol(LV_GetCount("Col"), 0) ; set width of final column to zero

    Gui, Show, Hide %Coords%

    Return


    ;-----------------------------------
    ; event handlers
    ;-----------------------------------
    LV_BoxGuiClose:  ; {Alt+F4} pressed, [X] clicked
    LV_BoxGuiEscape: ; {Esc} pressed
        Gui, Hide
    Return

    LV_BoxGuiSize:
        GuiControl, Move, SysListView321, w%A_GuiWidth% h%A_GuiHeight%
    Return
}
